@@ -36,6 +36,7 @@ cFCDialog_AddFile : public Gtk::FileChooserDialog
 		virtual ~cFCDialog_AddFile();
 		
 		void clear();
+		int run();
 
 	protected:
 	
@@ -74,6 +75,7 @@ cFCDialog_SaveAs : public Gtk::FileChooserDialog
 		virtual ~cFCDialog_SaveAs();
 		
 		void clear();
+		int run();
 		std::string	get_filename();
 	
 	protected:
@@ -128,18 +130,17 @@ cFCDialog_SelectFolder : public Gtk::FileChooserDialog
 	public:
 		         cFCDialog_SelectFolder( Gtk::Window& , const Glib::ustring& );
 		virtual ~cFCDialog_SelectFolder();
-		
-//		void init();
-//		std::string	get_filename();
-	
+
+		void clear();
+		int run();
+
 	protected:
 	
-//		void clear();
-
-//		Gtk::MessageDialog	mMDialog_OverwriteConfirm;
+		void init();
 };
 
 
+
 /*** File Chooser Button ******************************************************/
 
 // Class : FileChooserButton - PDF
@@ -149,12 +150,8 @@ cFCButton_Pdf : public Gtk::FileChooserButton
 	public:
 		         cFCButton_Pdf( Gtk::Window& , const Glib::ustring& );
 		virtual ~cFCButton_Pdf();
-		
-//		void init();
-		
-//	protected:
-		
-//		void clear();
+
+		void clear();
 };
 
 
@@ -165,12 +162,8 @@ cFCButton_Fdf : public Gtk::FileChooserButton
 	public:
 		         cFCButton_Fdf( Gtk::Window& , const Glib::ustring& );
 		virtual ~cFCButton_Fdf();
-		
-//		void init();
-		
-//	protected:
-		
-//		void clear();
+
+		void clear();
 };
 
 
@@ -182,11 +175,7 @@ cFCButton_Dump : public Gtk::FileChooserButton
 		         cFCButton_Dump( Gtk::Window& , const Glib::ustring& );
 		virtual ~cFCButton_Dump();
 
-//		void init();
-		
-//	protected:
-		
-//		void clear();
+		void clear();
 };
 
 
