@@ -37,17 +37,18 @@ main(
 */
 
 int
-main (
-	int argc ,
-	char *argv[] )
+main ( int argc , char *argv[] )
 {
 	Gtk::Main kit( argc , argv );
 	
 	cWindow_Main
 		*pWindow_Main = NULL;
 		
+	std::cout << std::endl << "PDF Chain " << VERSION
+		<< " - A graphical user interface for the PDF Toolkit"
+		<< std::endl << std::endl;
+
 	pWindow_Main = new cWindow_Main();
-	
 	if ( pWindow_Main ) {
 		kit.run( *pWindow_Main );
 	}
