@@ -185,8 +185,7 @@ Pdfchain::execute_command( const std::string& str_command )
 	if ( NULL != Pdfchain::pSBar )
 		message_id = Pdfchain::pSBar->push( _("Executing command ...") );
 	
-	std::cout << std::endl << "PDFTK command:";
-	std::cout << std::endl << str_command;
+	std::cout << "COMMAND: " << str_command << std::endl;
 
 	int error_code = system( str_command.c_str() );
 	
