@@ -19,6 +19,8 @@
 #ifndef __PDFCHAIN_CONFIG__
 #define __PDFCHAIN_CONFIG__
 
+#include "config.h"
+
 #include <iostream>
 //#include <limits>
 //#include <memory>
@@ -243,7 +245,8 @@ namespace Pdfchain {
 
 		// Features
 		extern const std::string ALLOW;
-		extern const std::string ALL_FEATURES;
+		extern const std::string FEATURES_ALL;
+//		extern const std::string FEATURES_NONE;
 
 		extern const std::string PRINTING;
 		extern const std::string DEGRADED_PRINTING;
@@ -257,7 +260,7 @@ namespace Pdfchain {
 		extern const std::string PASSWORD_OWNER;
 		extern const std::string PASSWORD_USER;
 
-		//extern const std::string ENCRYPT_NONE;
+//		extern const std::string ENCRYPT_NONE;
 		extern const std::string ENCRYPT_40BIT;
 		extern const std::string ENCRYPT_128BIT;
 
@@ -265,6 +268,7 @@ namespace Pdfchain {
 		extern const std::string UNPACK_FILES;
 		extern const std::string COMPRESS;
 		extern const std::string UNCOMPRESS;
+		extern const std::string DUMP_DATA_ANNOTS;
 		extern const std::string DUMP_DATA_FIELDS;
 		extern const std::string DUMP_DATA_FIELDS_UTF8;
 		extern const std::string DUMP_DATA;
@@ -274,6 +278,7 @@ namespace Pdfchain {
 		extern const std::string GENERATE_FDF;
 		extern const std::string FILL_FORM;
 		extern const std::string FLATTEN;
+		extern const std::string NEED_APPEARANCES;
 		extern const std::string DROP_XFA;
 	}
 }
