@@ -102,7 +102,7 @@ cLStore_OutputId::getTMCRecord()
 
 // Method (public) : select
 Gtk::TreeModel::iterator
-cLStore_OutputId::select( guchar output_id )
+cLStore_OutputId::select( guchar output_id )	// FIXME: use Pdfchain::Id::OutputId (enum) instead of guchar
 {
 	Gtk::TreeModel::iterator iter;
 	
