@@ -52,7 +52,7 @@ cLStore_OutputId : public Gtk::ListStore
 		static Glib::RefPtr<cLStore_OutputId> create();
 		cTMCRecord_Selection* getTMCRecord();
 
-		Gtk::TreeModel::iterator select( guchar );
+		Gtk::TreeModel::iterator select( guchar );	// FIXME: use Pdfchain::Id::OutputId (enum) instead of guchar
 		
 	protected:
 	
