@@ -870,17 +870,15 @@ cLStore_Cat::editPages(
 
 	iter->set_value( pTMCRecord->mTMColumn_Pages , str_pages );
 	
-	switch ( validateTMColumn_Pages( iter ) ) {
-		case true:
-			iter->set_value(
-				pTMCRecord->mTMColumn_Color_Pages ,
-				Pdfchain::Color::RGBA_VALID );
-			break;
-		default:
-			iter->set_value(
-				pTMCRecord->mTMColumn_Color_Pages ,
-				Pdfchain::Color::RGBA_INVALID );
-			break;
+	if ( true == validateTMColumn_Pages( iter ) ) {
+		iter->set_value(
+			pTMCRecord->mTMColumn_Color_Pages ,
+			Pdfchain::Color::RGBA_VALID );
+	}
+	else {
+		iter->set_value(
+			pTMCRecord->mTMColumn_Color_Pages ,
+			Pdfchain::Color::RGBA_INVALID );
 	}
 			
 	return;
@@ -999,13 +997,11 @@ cLStore_Cat::createCommand(
 
 	// Select Cat or Shuffle
 	str_command.append( " " );
-	switch ( shuffle ) {
-		case true:
-			str_command.append( Pdfchain::Cmd::SHUFFLE );
-			break;
-		default:
-			str_command.append( Pdfchain::Cmd::CAT );
-			break;
+	if ( true == shuffle ) {
+		str_command.append( Pdfchain::Cmd::SHUFFLE );
+	}
+	else {
+		str_command.append( Pdfchain::Cmd::CAT );
 	}
 
 	// Assign Pages, EvenOdd, Rotation on each handle
@@ -1013,48 +1009,42 @@ cLStore_Cat::createCommand(
 		if ( G_MAXUINT > ( file_id = iter_row->get_value( pTMCRecord->mTMColumn_Id ) ) ) {
 
 			// Create command
-			switch ( validateTMColumn_Pages( iter_row ) ) {
+			if ( true != validateTMColumn_Pages( iter_row ) ) {
+				return "";
+			}
+			else {
+				std::string::size_type
+					pos_a = 0,
+					pos_b = 0;
 
-				case false:
-					return "";
-					break;
+				std::string
+					str_pages = Glib::filename_from_utf8(
+						iter_row->get_value( pTMCRecord->mTMColumn_Pages ) );
+					
+				while ( str_pages.length() > pos_a
+					&& str_pages.length() > pos_b ) {
 
-				case true: {
+					// Find begin and end of an argument (arguments are separated by ' ')
+					for ( pos_a = pos_b ;
+						str_pages.length() > pos_a && 0 == str_pages.compare( pos_a , 1 , " " ) ;
+						pos_a++ );	// Skips all ' '
 
-					std::string::size_type
-						pos_a = 0,
-						pos_b = 0;
+					for ( pos_b = pos_a ;
+						str_pages.length() > pos_b && 0 != str_pages.compare( pos_b , 1 , " " ) ;
+						pos_b++ );	// Skips all characters, without ' '
 
-					std::string
-						str_pages = Glib::filename_from_utf8(
-							iter_row->get_value( pTMCRecord->mTMColumn_Pages ) );
-						
-					while ( str_pages.length() > pos_a
-						&& str_pages.length() > pos_b ) {
+					// Append argument
+					str_command.append( " " );
+					str_command.append( getHandle( file_id ) );
+					str_command.append( str_pages.substr( pos_a , pos_b - pos_a ) );
 
-						// Find begin and end of an argument (arguments are separated by ' ')
-						for ( pos_a = pos_b ;
-							str_pages.length() > pos_a && 0 == str_pages.compare( pos_a , 1 , " " ) ;
-							pos_a++ );	// Skips all ' '
+					// EvenOdd (only it there is a page range sign "-" at pages string)
+					if ( std::string::npos != ( str_pages.substr( pos_a , pos_b - pos_a )).find( "-" ) )
+						str_command.append( iter_row->get_value( pTMCRecord->mTMColumn_Cmd_EvenOdd ) );
 
-						for ( pos_b = pos_a ;
-							str_pages.length() > pos_b && 0 != str_pages.compare( pos_b , 1 , " " ) ;
-							pos_b++ );	// Skips all characters, without ' '
-
-						// Append argument
-						str_command.append( " " );
-						str_command.append( getHandle( file_id ) );
-						str_command.append( str_pages.substr( pos_a , pos_b - pos_a ) );
-
-						// EvenOdd (only it there is a page range sign "-" at pages string)
-						if ( std::string::npos != ( str_pages.substr( pos_a , pos_b - pos_a )).find( "-" ) )
-							str_command.append( iter_row->get_value( pTMCRecord->mTMColumn_Cmd_EvenOdd ) );
-
-						// Rotation
-						str_command.append( iter_row->get_value( pTMCRecord->mTMColumn_Cmd_Rotation ) );
-					}
+					// Rotation
+					str_command.append( iter_row->get_value( pTMCRecord->mTMColumn_Cmd_Rotation ) );
 				}
-				break;
 			}
 		}
 	}
