@@ -95,17 +95,19 @@ cLStore_Cat : public Gtk::ListStore
 		
 		void clear();
 
-		void addRows(      Glib::RefPtr<Gtk::TreeSelection> );
-		void removeRows(   Glib::RefPtr<Gtk::TreeSelection> );
-		void copyRows(     Glib::RefPtr<Gtk::TreeSelection> );
-		void moveRowsUp(   Glib::RefPtr<Gtk::TreeSelection> );
-		void moveRowsDown( Glib::RefPtr<Gtk::TreeSelection> );
+		void addRows(           Glib::RefPtr<Gtk::TreeView::Selection> );
+		void removeRows(        Glib::RefPtr<Gtk::TreeView::Selection> );
+		void copyRows(          Glib::RefPtr<Gtk::TreeView::Selection> );
+		void moveRows_Up(       Glib::RefPtr<Gtk::TreeView::Selection> );
+		void moveRows_Down(     Glib::RefPtr<Gtk::TreeView::Selection> );
+		void moveRows_ToTop(    Glib::RefPtr<Gtk::TreeView::Selection> );
+		void moveRows_ToBottom( Glib::RefPtr<Gtk::TreeView::Selection> );
 
-		void toggleAdd(      const Gtk::TreePath& );
-		void editPages(      const Gtk::TreePath& , const Glib::ustring& );
-		void changeEvenOdd(  const Gtk::TreePath& , const Glib::ustring& , const std::string& );
-		void changeRotation( const Gtk::TreePath& , const Glib::ustring& , const std::string& );
-		void editPassword(   const Gtk::TreePath& , const Glib::ustring& );
+		void toggleAdd(      const Gtk::TreeModel::Path& );
+		void editPages(      const Gtk::TreeModel::Path& , const Glib::ustring& );
+		void changeEvenOdd(  const Gtk::TreeModel::Path& , const Glib::ustring& , const std::string& );
+		void changeRotation( const Gtk::TreeModel::Path& , const Glib::ustring& , const std::string& );
+		void editPassword(   const Gtk::TreeModel::Path& , const Glib::ustring& );
 
 		std::string createCommand( bool );
 
