@@ -43,7 +43,8 @@ cTView_Attach::cTView_Attach( Gtk::Window& ref_window )
 	set_model( rLStore_Attach );
 	set_reorderable( true );
 	set_rules_hint( true );
-	set_rubber_banding( true );
+//	set_rubber_banding( true );
+	set_rubber_banding( false );
 	set_enable_search( true );
 	set_search_column( pTMCRecord_Attach->mTMColumn_AttachFile );
 	set_tooltip_column( get_search_column() + 2 );
