@@ -29,19 +29,20 @@
 class
 cCBox_CountingBase : public Gtk::ComboBox
 {
-//	friend class cTable_Burst;
 	friend class cSection_Burst;
 	
 	public:
 
+		// Constructor
 		         cCBox_CountingBase();
 		virtual ~cCBox_CountingBase();
 		
 	protected:
 
+		// Anchors
 		Glib::RefPtr<cLStore_CountingBase> rLStore;
-		Gtk::CellRendererText					mCRText;
-		cTMCRecord_Selection*					pTMCRecord;		
+		Gtk::CellRendererText mCRText;
+		cTMCRecord_Selection* pTMCRecord;		
 };
 
 
@@ -49,47 +50,98 @@ cCBox_CountingBase : public Gtk::ComboBox
 /*** Section Burst ************************************************************/
 
 class
-cSection_Burst : public Gtk::Table
+cSection_Burst : public Gtk::VBox
 {
 	public:
+
+		// Constructor
 		         cSection_Burst( Gtk::Window& );
 		virtual ~cSection_Burst();
 		
+		// Methodes
 		void clear();
 		std::string createCommand();
 		
 	private:
 	
+		// Methodes
 		void init();
 	
-		Glib::ustring sPrefix,
-		              sSuffix;
-		guint         vPageNumbers;
-		guint         vDigits_Oct,
-		              vDigits_Dec,
-		              vDigits_Hex;
+		// Variables
+		const Glib::ustring
+			sPrefix ,
+			sSuffix;
+
+		guint
+			vPageNumbers ,
+			vDigits_Oct ,
+			vDigits_Dec ,
+			vDigits_Hex;
+
+		Glib::RefPtr<Gtk::SizeGroup>
+			rSGroup_LabelPattern;
+
+		// Widgets
+		Gtk::HBox
+			mHBox_SourceFile ,
+			mHBox_Prefix ,
+			mHBox_Digits;
+
+		Gtk::VBox
+			mVBox_Pattern;
+
+		Gtk::Table
+			mTable_Extended;
+
+		Gtk::Frame
+			mFrame_Pattern;
+
+		Gtk::Expander
+			mExpander_Extended;
+
+		Gtk::Label
+			mLabel_Pattern ,
+			mLabel_Extended ,
+			mLabel_SourceFile ,
+			mLabel_Prefix ,
+			mLabel_Base ,
+			mLabel_Digits ,
+			mLabel_Suffix;
+
+		Gtk::Entry
+			mEntry_Prefix ,
+		    mEntry_Suffix;
+
+		Glib::RefPtr<Gtk::Adjustment>	// Declaration of Glib::RefPtr<Gtk::Adjustment> before Gtk::SpinButton!!!
+			rAdjust_Digits;
+
+		Gtk::SpinButton					// Declaration of Gtk::SpinButton behind Glib::RefPtr<Gtk::Adjustment>!!!
+			mSButton_Digits;
+
+		Gtk::RadioButton				// Declaration of Gtk::RadioButton before Gtk::RadioButtonGroup!!!
+			mRButton_Auto ,
+		    mRButton_Manual;
+
+		Gtk::RadioButtonGroup			// Declaration of Gtk::RadioButtonGroup behind Gtk::RadioButton!!!
+			mRBGroup_CounterDigits;
+
+		Gtk::CheckButton
+			mCButton_Extension;
+
+		cCBox_CountingBase
+			mCBox_CountingBase;
+
+		cFCButton_Pdf
+			mFCButton_SourceFile;
+
+		cFCDialog_SelectFolder
+			mFCDialog_SelectFolder;
+
+		// Signal Handler
+		inline void onFCButton_SourceFile_file_set() {
 
-		Gtk::HBox                     mHBox_Digits;
-		Gtk::Label                    mLabel_SourceFile,
-		                              mLabel_Prefix,
-		                              mLabel_Base,
-		                              mLabel_Digits,
-		                              mLabel_Suffix,
-		                              mLabel_Extension;
-		cFCButton_Pdf                 mFCButton_SourceFile;
-		Gtk::Entry                    mEntry_Prefix,
-		                              mEntry_Suffix;
-		Glib::RefPtr<Gtk::Adjustment> rAdjust_Digits;			// Declaration of Adjustment before SpinButton!
-		Gtk::SpinButton               mSButton_Digits;
-		Gtk::RadioButton              mRButton_Auto,
-		                              mRButton_Manual;
-		Gtk::Switch                   mSwitch_Extension;
-		cCBox_CountingBase            mCBox_CountingBase;
-		Gtk::RadioButtonGroup         mRBGroup_CounterDigits;
-		cFCDialog_SelectFolder        mFCDialog_SelectFolder;
-		
-		void onFCButton_SourceFile_file_set() {
 			vPageNumbers = Pdfchain::count_page_numbers( mFCButton_SourceFile.get_filename() );
+
 			vDigits_Oct = Pdfchain::count_digits_of_guint_oct( vPageNumbers );
 			vDigits_Dec = Pdfchain::count_digits_of_guint_dec( vPageNumbers );
 			vDigits_Hex = Pdfchain::count_digits_of_guint_hex( vPageNumbers );
@@ -98,23 +150,33 @@ cSection_Burst : public Gtk::Table
 			return;
 		}
 		
-		void onEntryIcon_Prefix_pressed( Gtk::EntryIconPosition icon_pos , const GdkEventButton* event ) {
+		inline void onEntryIcon_Prefix_pressed( 
+			Gtk::EntryIconPosition icon_pos ,
+			const GdkEventButton* event )
+		{
 			mEntry_Prefix.set_text( sPrefix );
 			return;
 		}
 		
-		void onCBox_CountingBase_changed() {
-			Gtk::TreeModel::iterator iter      = mCBox_CountingBase.get_active();
-			cTMCRecord_Selection*    pt_record = mCBox_CountingBase.rLStore->getTMCRecord();
+		inline void onCBox_CountingBase_changed() {
+
+			Gtk::TreeModel::iterator
+				iter = mCBox_CountingBase.get_active();
+
+			cTMCRecord_Selection*
+				pt_record = mCBox_CountingBase.rLStore->getTMCRecord();
 
 			if ( mRButton_Auto.get_active() ) {
 				switch ( (*iter)[pt_record->mTMColumn_ID] ) {
+
 					case Pdfchain::Id::COUNT_OCT:
 						rAdjust_Digits->set_value( static_cast<double>( vDigits_Oct ) );
 						break;
+				
 					case Pdfchain::Id::COUNT_DEC:
 						rAdjust_Digits->set_value( static_cast<double>( vDigits_Dec ) );
 						break;
+					
 					case Pdfchain::Id::COUNT_HEX:
 						rAdjust_Digits->set_value( static_cast<double>( vDigits_Hex ) );
 						break;
@@ -124,13 +186,16 @@ cSection_Burst : public Gtk::Table
 			return;
 		}
 
-		void onRButton_Auto_toggled() {
+		inline void onRButton_Auto_toggled() {
 			mSButton_Digits.set_sensitive( mRButton_Manual.get_active() );
 			onCBox_CountingBase_changed();
 			return;
 		}
 		
-		void onEntryIcon_Suffix_pressed( Gtk::EntryIconPosition icon_pos , const GdkEventButton* event ) {
+		inline void onEntryIcon_Suffix_pressed(
+			Gtk::EntryIconPosition icon_pos ,
+			const GdkEventButton* event )
+		{
 			mEntry_Suffix.set_text( sSuffix );
 			return;
 		}
