@@ -155,7 +155,7 @@ cPMenu_Cat::cPMenu_Cat( cTView_Cat* pt_tview_cat )
 cPMenu_Cat::~cPMenu_Cat()
 {
 #ifdef PDFCHAIN_TEST
-	std::cout << std::endl << "cPMenu_Cat::~cPMenu_Cat()");	//TEST
+	std::cout << std::endl << "cPMenu_Cat::~cPMenu_Cat()";	//TEST
 #endif
 }
 
@@ -180,6 +180,7 @@ cTView_Cat::cTView_Cat( Gtk::Window& ref_window )
 
 	mLabel_Add(         _("Add")            , false ),	// label , mnemonic
 	mLabel_Pages(       _("Page selection") , false ),
+	mLabel_EvenOdd(     _("Page filter")    , false ),
 	mLabel_Rotation(    _("Rotation")       , false ),
 	mLabel_SourceFile(  _("Document")       , false ),
 	mLabel_Password(    _("Password")       , false ),
@@ -199,7 +200,8 @@ cTView_Cat::cTView_Cat( Gtk::Window& ref_window )
 	set_model( rLStore_Cat );
 	set_reorderable( true );
 	set_rules_hint( true );
-	set_rubber_banding( true );
+//	set_rubber_banding( true );
+	set_rubber_banding( false );
 	set_enable_search( true );
 	set_search_column( pTMCRecord_Cat->mTMColumn_SourceFile );
 	set_tooltip_column( get_search_column() + 2 );
@@ -207,8 +209,9 @@ cTView_Cat::cTView_Cat( Gtk::Window& ref_window )
 	mLabel_Add.set_tooltip_text(         _("Add entry for processing") );
 	mLabel_Pages.set_tooltip_text(       _("Select and filter pages"
 		"\nE.g.: '1-3 5 7-end' or '1 r5 r3-end' or 'end-3 3 3 3-end'"
-		"\n'r' means 'reverse' (e.g. 'r2' is the second last page)."
-		"\nThe 'even' and 'odd' filters only affect to page ranges (not to single pages)!") );
+		"\n'r' means 'reverse' (e.g. 'r2' is the second last page).") );
+	mLabel_EvenOdd.set_tooltip_text( _("Filters pages with an AND logic to the page selection."
+		"\nThe 'even' and 'odd' filters only affect to page ranges (not to single selected pages)!") );
 /*
 	mLabel_Pages.set_tooltip_text(       _("Select and filter pages\n"
 		"Single pages and page ranges are separated by the space sign (e.g.: '3 5 4-6'). "
@@ -225,6 +228,7 @@ cTView_Cat::cTView_Cat( Gtk::Window& ref_window )
 
 	mTVColumn_Add.set_widget(         mLabel_Add );
 	mTVColumn_Pages.set_widget(       mLabel_Pages );
+	mTVColumn_EvenOdd.set_widget(     mLabel_EvenOdd );
 	mTVColumn_Rotation.set_widget(    mLabel_Rotation );
 	mTVColumn_SourceFile.set_widget(  mLabel_SourceFile );
 	mTVColumn_SourcePath.set_widget(  mLabel_SourcePath );
@@ -233,6 +237,7 @@ cTView_Cat::cTView_Cat( Gtk::Window& ref_window )
 
 	mLabel_Add.show();
 	mLabel_Pages.show();
+	mLabel_EvenOdd.show();
 	mLabel_Rotation.show();
 	mLabel_SourceFile.show();
 	mLabel_SourcePath.show();
@@ -242,6 +247,7 @@ cTView_Cat::cTView_Cat( Gtk::Window& ref_window )
 	mTVColumn_Add.set_resizable( false );
 	mTVColumn_Pages.set_expand( true );
 	mTVColumn_Pages.set_resizable( true );
+	mTVColumn_EvenOdd.set_resizable( false );
 	mTVColumn_Rotation.set_resizable( false );
 	mTVColumn_SourceFile.set_expand( true );
 	mTVColumn_SourceFile.set_resizable( true );
@@ -274,12 +280,12 @@ cTView_Cat::cTView_Cat( Gtk::Window& ref_window )
 
 	mTVColumn_Add.pack_start(         mCRToggle_Add               , false );	// cell renderer , expand
 	mTVColumn_Pages.pack_start(       mCRText_Pages	              , true  );
-	mTVColumn_Pages.pack_start(       mCRCombo_EvenOdd            , false );
+	mTVColumn_EvenOdd.pack_start(     mCRCombo_EvenOdd            , false );
 	mTVColumn_Rotation.pack_start(    mCRCombo_Rotation	          , false );
 	mTVColumn_SourceFile.pack_start(  mCRText_SourceFile          , true  );
 	mTVColumn_Password.pack_start(    mCRText_Password            , true  );
 	mTVColumn_PageNumbers.pack_start( mCRText_PageNumbers         , true  );
-	
+
 #ifdef PDFCHAIN_TEMP
 	mTVColumn_Id.pack_start(          mCRText_Id                  , true  );	//TEMP
 	mTVColumn_SourcePath.pack_start(  mCRText_SourcePath          , true  );	//TEMP
@@ -303,7 +309,7 @@ cTView_Cat::cTView_Cat( Gtk::Window& ref_window )
 		mCRText_Pages.property_foreground_rgba() ,
 		pTMCRecord_Cat->mTMColumn_Color_Pages );
 	
-	mTVColumn_Pages.add_attribute(
+	mTVColumn_EvenOdd.add_attribute(
 		mCRCombo_EvenOdd.property_text() ,
 		pTMCRecord_Cat->mTMColumn_EvenOdd );
 	
@@ -359,6 +365,7 @@ cTView_Cat::cTView_Cat( Gtk::Window& ref_window )
 	
 	append_column( mTVColumn_Add         );
 	append_column( mTVColumn_Pages       );
+	append_column( mTVColumn_EvenOdd     );
 	append_column( mTVColumn_Rotation    );
 	append_column( mTVColumn_SourceFile  );
 	append_column( mTVColumn_Password    );
