@@ -315,9 +315,10 @@ cSection_Tool::createCommand()
 			else if ( mRButton_DumpDataFields.get_active() ) {
 				str_command  = " " + Pdfchain::quote_path( str_sourcefile );
 
-				switch ( mCButton_DumpDataFields_Utf8.get_active() ) {
-					case true:	str_command += " " + Pdfchain::Cmd::DUMP_DATA_FIELDS_UTF8;	break;
-					default:	str_command += " " + Pdfchain::Cmd::DUMP_DATA_FIELDS;		break;
+				if ( true == mCButton_DumpDataFields_Utf8.get_active() ) {
+					str_command += " " + Pdfchain::Cmd::DUMP_DATA_FIELDS_UTF8;
+				} else {
+					str_command += " " + Pdfchain::Cmd::DUMP_DATA_FIELDS;
 				}
 				str_command += " " + Pdfchain::Cmd::OUTPUT;
 				str_command += " " + Pdfchain::quote_path( str_output );
@@ -325,9 +326,10 @@ cSection_Tool::createCommand()
 			else if ( mRButton_DumpData.get_active() ) {
 				str_command  = " " + Pdfchain::quote_path( str_sourcefile );
 				
-				switch ( mCButton_DumpData_Utf8.get_active() ) {
-					case true:	str_command += " " + Pdfchain::Cmd::DUMP_DATA_UTF8;	break;
-					default:	str_command += " " + Pdfchain::Cmd::DUMP_DATA;		break;
+				if ( true == mCButton_DumpData_Utf8.get_active() ) {
+					str_command += " " + Pdfchain::Cmd::DUMP_DATA_UTF8;
+				} else {
+					str_command += " " + Pdfchain::Cmd::DUMP_DATA;
 				}
 				str_command += " " + Pdfchain::Cmd::OUTPUT;
 				str_command += " " + Pdfchain::quote_path( str_output );
@@ -335,9 +337,10 @@ cSection_Tool::createCommand()
 			else if ( mRButton_UpdateInfo.get_active() ) {
 				str_command  = " " + Pdfchain::quote_path( str_sourcefile );
 
-				switch ( mCButton_UpdateInfo_Utf8.get_active() ) {
-					case true:	str_command += " " + Pdfchain::Cmd::UPDATE_INFO_UTF8;	break;
-					default:	str_command += " " + Pdfchain::Cmd::UPDATE_INFO;		break;
+				if ( true == mCButton_UpdateInfo_Utf8.get_active() ) {
+					str_command += " " + Pdfchain::Cmd::UPDATE_INFO_UTF8;
+				} else {
+					str_command += " " + Pdfchain::Cmd::UPDATE_INFO;
 				}
 				str_command += " " + Pdfchain::quote_path( str_dumpfile );
 				str_command += " " + Pdfchain::Cmd::OUTPUT;
