@@ -41,47 +41,69 @@ cSection_Tool : public Gtk::VBox
 
 		Glib::RefPtr<Gtk::SizeGroup> rSGroup_FCButton;
 
-		Gtk::HBox             mHBox_SourceFile,
-		                      mHBox_UpdateInfo,
-		                      mHBox_FillForm;
-		Gtk::ScrolledWindow   mSWindow_Tool;
-		Gtk::Table            mTable_Tool;
-		Gtk::Label            mLabel_SourceFile,
-		                      mLabel_DumpDataFile,
-		                      mLabel_FdfFile;
-		Gtk::RadioButton      mRButton_UnpackFiles,
-		                      mRButton_Compress,
-		                      mRButton_Uncompress,
-		                      mRButton_DumpDataFields,
-		                      mRButton_DumpData,
-		                      mRButton_UpdateInfo,
-		                      mRButton_GenerateFdf,
-		                      mRButton_FillForm,
-		                      mRButton_Flatten,
-		                      mRButton_DropXfa;
-		Gtk::RadioButtonGroup mRBGroup_Tool;
-		Gtk::CheckButton      mCButton_DumpDataFields_Utf8,
-		                      mCButton_DumpData_Utf8,
-		                      mCButton_UpdateInfo_Utf8,
-		                      mCButton_FillForm_DropXfa,
-		                      mCButton_FillForm_Flatten;
-		Gtk::Separator        mHSeparator_A,
-		                      mHSeparator_B,
-		                      mHSeparator_C,
-		                      mVSeparator_FillForm;
-		cFCButton_Pdf         mFCButton_SourceFile;
-		cFCButton_Dump        mFCButton_DumpDataFile;
-		cFCButton_Fdf         mFCButton_FdfFile;
+		Gtk::HBox
+			mHBox_SourceFile ,
+			mHBox_UpdateInfo ,
+			mHBox_FillForm;
+
+		Gtk::ScrolledWindow
+			mSWindow_Tool;
+
+		Gtk::Table
+			mTable_Tool;
+
+		Gtk::Label
+			mLabel_SourceFile ,
+			mLabel_DumpDataFile ,
+			mLabel_FdfFile;
+
+		Gtk::RadioButton
+			mRButton_Repair ,
+			mRButton_UnpackFiles ,
+			mRButton_Compress ,
+			mRButton_Uncompress ,
+			mRButton_DumpDataAnnots ,
+			mRButton_DumpDataFields ,
+			mRButton_DumpData ,
+			mRButton_UpdateInfo ,
+			mRButton_GenerateFdf ,
+			mRButton_FillForm ,
+			mRButton_Flatten ,
+			mRButton_DropXfa;
+
+		Gtk::RadioButtonGroup
+			mRBGroup_Tool;
+
+		Gtk::CheckButton
+			mCButton_DumpDataFields_Utf8 ,
+			mCButton_DumpData_Utf8 ,
+			mCButton_UpdateInfo_Utf8 ,
+			mCButton_FillForm_DropXfa ,
+			mCButton_FillForm_Flatten ,
+			mCButton_FillForm_Appearance;
+
+		Gtk::Separator
+			mHSeparator_A ,
+			mHSeparator_B ,
+			mHSeparator_C ,
+			mHSeparator_D ,
+			mVSeparator_FillForm;
+
+		Gtk::Alignment
+			mAlign_HSeparatorA ,
+			mAlign_HSeparatorB ,
+			mAlign_HSeparatorC ,
+			mAlign_HSeparatorD;
+
+		cFCButton_Pdf  mFCButton_SourceFile;
+		cFCButton_Dump mFCButton_DumpDataFile;
+		cFCButton_Fdf  mFCButton_FdfFile;
 		
 		cFCDialog_SelectFolder mFCDialog_SelectFolder;
 		cFCDialog_SaveAs_Pdf   mFCDialog_SaveAs_Pdf;
 		cFCDialog_SaveAs_Fdf   mFCDialog_SaveAs_Fdf;
 		cFCDialog_SaveAs_Dump  mFCDialog_SaveAs_Dump;
 
-		Gtk::Alignment        mAlign_HSeparatorA,
-		                      mAlign_HSeparatorB,
-		                      mAlign_HSeparatorC;
-
 		void onRButton_DumpDataFields_toggled() {
 			mCButton_DumpDataFields_Utf8.set_sensitive( mRButton_DumpDataFields.get_active() );
 			return;
@@ -105,8 +127,22 @@ cSection_Tool : public Gtk::VBox
 			mVSeparator_FillForm.set_sensitive(			mRButton_FillForm.get_active() );
 			mCButton_FillForm_DropXfa.set_sensitive(	mRButton_FillForm.get_active() );
 			mCButton_FillForm_Flatten.set_sensitive(	mRButton_FillForm.get_active() );
+			mCButton_FillForm_Appearance.set_sensitive(	mRButton_FillForm.get_active() );
 			return;
 		}
+
+		void onCButton_FillForm_Flatten_toggled() {
+			if( mCButton_FillForm_Flatten.get_active() )
+				mCButton_FillForm_Appearance.set_active( false );
+			return;
+		}
+
+		void onCButton_FillForm_Appearance_toggled() {
+			if( mCButton_FillForm_Appearance.get_active() )
+				mCButton_FillForm_Flatten.set_active( false );
+			return;
+		}
+
 };
 
 
